@@ -124,7 +124,7 @@ class Experiment(Base, ArtifactMixin, DataframeMixin, TagMixin):
 
         return metric
 
-    def log_feature(self, name, description=None, importance=None):
+    def log_feature(self, name, description=None, importance=None, tags=[]):
         """Create a feature under the experiment.
 
         Parameters
@@ -136,30 +136,44 @@ class Experiment(Base, ArtifactMixin, DataframeMixin, TagMixin):
             additional context.
         importance : float
             The feature's importance.
+        tags : list of str, optional
+            Values to tag the experiment with. Use tags to organize and
+            filter your features.
 
         Returns
         -------
         rubicon.client.Feature
             The created feature.
         """
-        feature = domain.Feature(name, description=description, importance=importance)
+        feature = domain.Feature(name, description=description, importance=importance, tags=tags)
         self.repository.create_feature(feature, self.project.name, self.id)
 
-        return Feature(feature, self._config)
+        return Feature(feature, self)
 
-    def features(self):
+    def features(self, name=None, tags=[], qtype="or"):
         """Get the features logged to this experiment.
 
+         Parameters
+        ----------
+        name : str, optional
+            The name value to filter results on.
+        tags : list of str, optional
+            The tag values to filter results on.
+        qtype : str, optional
+            The query type to filter results on. Can be 'or' or
+            'and'. Defaults to 'or'.
+
         Returns
         -------
         list of rubicon.client.Feature
             The features previously logged to this experiment.
         """
-        self._features = [
-            Feature(f, self._config)
-            for f in self.repository.get_features(self.project.name, self.id)
+
+        features = [
+            Feature(f, self) for f in self.repository.get_features(self.project.name, self.id)
         ]
 
+        self._features = filter_children(features, tags, qtype, name)
         return self._features
 
     def feature(self, name=None, id=None):
@@ -182,13 +196,13 @@ class Experiment(Base, ArtifactMixin, DataframeMixin, TagMixin):
 
         if name is not None:
             feature = self.repository.get_feature(self.project.name, self.id, name)
-            feature = Feature(feature, self._config)
+            feature = Feature(feature, self)
         else:
             feature = [f for f in self.features() if f.id == id][0]
 
         return feature
 
-    def log_parameter(self, name, value=None, description=None):
+    def log_parameter(self, name, value=None, description=None, tags=[]):
         """Create a parameter under the experiment.
 
         Parameters
@@ -202,30 +216,45 @@ class Experiment(Base, ArtifactMixin, DataframeMixin, TagMixin):
         description : str, optional
             The parameter's description. Use to provide
             additional context.
+        tags : list of str, optional
+            Values to tag the parameter with. Use tags to organize and
+            filter your parameters.
 
         Returns
         -------
         rubicon.client.Parameter
             The created parameter.
         """
-        parameter = domain.Parameter(name, value=value, description=description)
+        parameter = domain.Parameter(name, value=value, description=description, tags=tags)
         self.repository.create_parameter(parameter, self.project.name, self.id)
 
-        return Parameter(parameter, self._config)
+        return Parameter(parameter, self)
 
-    def parameters(self):
+    def parameters(self, name=None, tags=[], qtype="or"):
         """Get the parameters logged to this experiment.
 
+        Parameters
+        ----------
+        name : str, optional
+            The name value to filter results on.
+        tags : list of str, optional
+            The tag values to filter results on.
+        qtype : str, optional
+            The query type to filter results on. Can be 'or' or
+            'and'. Defaults to 'or'.
+
         Returns
         -------
         list of rubicon.client.Parameter
             The parameters previously logged to this experiment.
         """
-        self._parameters = [
-            Parameter(p, self._config)
-            for p in self.repository.get_parameters(self.project.name, self.id)
+
+        parameters = [
+            Parameter(p, self) for p in self.repository.get_parameters(self.project.name, self.id)
         ]
 
+        self._parameters = filter_children(parameters, tags, qtype, name)
+
         return self._parameters
 
     def parameter(self, name=None, id=None):
@@ -248,7 +277,7 @@ class Experiment(Base, ArtifactMixin, DataframeMixin, TagMixin):
 
         if name is not None:
             parameter = self.repository.get_parameter(self.project.name, self.id, name)
-            parameter = Parameter(parameter, self._config)
+            parameter = Parameter(parameter, self)
         else:
             parameter = [p for p in self.parameters() if p.id == id][0]
 
